MSA Framework for Kubernetes

# AuroraStack: An Python-based Open Source MSA Framework for Developing gRPC based Microservice Architectures

AuroraStack is an open source framework that helps developers easily build and manage microservice architectures. It provides the following core features:

* gRPC Server: run Server as gRPC interface
* Rest Server: run Server as restapi interface
* Scheduler: run Server as cron like trigger

AuroraStack offers the following benefits:

* Simplicity: Designed to be easy for developers to build and manage microservice architectures.
* Scalability: Designed to be scalable for applications of all sizes.
* Flexibility: Designed to integrate with a variety of open source tools.

# Getting Started

To get started with AuroraStack,

```
pip3 install aurorastack-core
```

# Community
